@@ -30,14 +30,18 @@
 
 #ifndef Q_OS_WIN
 #include <unistd.h>
+
+// needed for umask application
+#include <sys/types.h>
+#include <sys/stat.h>
 #endif
 
 #include <QSaveFile>
 
 #if 0
-#define BUFFER_DEBUG qCDebug(LOG_PART)
+#define BUFFER_DEBUG qCDebug(LOG_KTE)
 #else
-#define BUFFER_DEBUG if (0) qCDebug(LOG_PART)
+#define BUFFER_DEBUG if (0) qCDebug(LOG_KTE)
 #endif
 
 namespace Kate
@@ -695,7 +699,7 @@ bool TextBuffer::load(const QString &filename, bool &encodingErrors, bool &tooLo
         }
     }
 
-    // save md5sum of file on disk
+    // save checksum of file on disk
     setDigest(file.digest());
 
     // remember if BOM was found
@@ -735,9 +739,9 @@ const QByteArray &TextBuffer::digest() const
     return m_digest;
 }
 
-void TextBuffer::setDigest(const QByteArray &md5sum)
+void TextBuffer::setDigest(const QByteArray &checksum)
 {
-    m_digest = md5sum;
+    m_digest = checksum;
 }
 
 void TextBuffer::setTextCodec(QTextCodec *codec)
@@ -759,6 +763,10 @@ bool TextBuffer::save(const QString &filename)
     // codec must be set!
     Q_ASSERT(m_textCodec);
 
+#ifndef Q_OS_WIN
+    const bool newFile = !QFile::exists(filename);
+#endif
+
     /**
      * use QSaveFile for save write + rename
      */
@@ -775,9 +783,6 @@ bool TextBuffer::save(const QString &filename)
     KCompressionDevice::CompressionType type = KFilterDev::compressionTypeForMimeType(m_mimeTypeForFilterDev);
     KCompressionDevice file(&saveFile, false, type);
 
-    /**
-     * try to open, if new file
-     */
     if (!file.open(QIODevice::WriteOnly)) {
         return false;
     }
@@ -853,6 +858,16 @@ bool TextBuffer::save(const QString &filename)
         m_history.setLastSavedRevision();
     }
 
+#ifndef Q_OS_WIN
+    if (ok && newFile) { // QTemporaryFile sets permissions to 0600, so fixing this
+        const mode_t mask = umask(0);
+        umask(mask);
+
+        const mode_t fileMode = 0666 & ~mask;
+        chmod(QFile::encodeName(filename).constData(), fileMode);
+    }
+#endif
+
     // report CODEC + ERRORS
     BUFFER_DEBUG << "Saved file " << filename << "with codec" << m_textCodec->name() << (ok ? "without" : "with") << "errors";
 
