@@ -36,7 +36,6 @@
 #include "katedocument.h"
 #include "kateglobal.h"
 #include "kateschema.h"
-#include "katesyntaxdocument.h"
 #include "katemodeconfigpage.h"
 #include "kateview.h"
 #include "spellcheck/spellcheck.h"
@@ -60,13 +59,12 @@
 #include <KCharsets>
 #include <KColorCombo>
 #include <KComboBox>
+#include <KIconLoader>
 #include "katepartdebug.h"
 #include "kateabstractinputmodefactory.h"
-#include <KIconLoader>
 #include <KShortcutsDialog>
 #include <KLineEdit>
 #include <KMessageBox>
-#include <KMimeTypeChooser>
 #include <KProcess>
 #include <KRun>
 #include <KSeparator>
@@ -197,11 +195,9 @@ void KateIndentConfigTab::apply()
 
 void KateIndentConfigTab::reload()
 {
-    ui->sbTabWidth->setSpecialValueText(ki18nc("spinbox special value for 1","1 character").toString());//(ki18np(" character", " characters").toString());
-    ui->sbTabWidth->setSuffix(ki18nc("suffix for spinbox >1", " characters").toString());
+    ui->sbTabWidth->setSuffix(ki18np(" character", " characters"));
     ui->sbTabWidth->setValue(KateDocumentConfig::global()->tabWidth());
-    ui->sbIndentWidth->setSpecialValueText(ki18nc("spinbox special value for 1","1 character").toString());
-    ui->sbIndentWidth->setSuffix(ki18nc("suffix for spinbox >1", " characters").toString());
+    ui->sbIndentWidth->setSuffix(ki18np(" character", " characters"));
     ui->sbIndentWidth->setValue(KateDocumentConfig::global()->indentationWidth());
     ui->chkKeepExtraSpaces->setChecked(KateDocumentConfig::global()->keepExtraSpaces());
     ui->chkIndentPaste->setChecked(KateDocumentConfig::global()->indentPastedText());
@@ -255,6 +251,7 @@ KateCompletionConfigTab::KateCompletionConfigTab(QWidget *parent)
 
     connect(ui->chkAutoCompletionEnabled, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(ui->gbWordCompletion, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+    connect(ui->gbKeywordCompletion, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(ui->minimalWordLength, SIGNAL(valueChanged(int)), this, SLOT(slotChanged()));
     connect(ui->removeTail, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
 
@@ -285,6 +282,7 @@ void KateCompletionConfigTab::apply()
     KateViewConfig::global()->setWordCompletion(ui->gbWordCompletion->isChecked());
     KateViewConfig::global()->setWordCompletionMinimalWordLength(ui->minimalWordLength->value());
     KateViewConfig::global()->setWordCompletionRemoveTail(ui->removeTail->isChecked());
+    KateViewConfig::global()->setKeywordCompletion(ui->gbKeywordCompletion->isChecked());
     KateViewConfig::global()->configEnd();
 }
 
@@ -293,6 +291,7 @@ void KateCompletionConfigTab::reload()
     ui->chkAutoCompletionEnabled->setChecked(KateViewConfig::global()->automaticCompletionInvocation());
     ui->gbWordCompletion->setChecked(KateViewConfig::global()->wordCompletion());
     ui->minimalWordLength->setValue(KateViewConfig::global()->wordCompletionMinimalWordLength());
+    ui->gbKeywordCompletion->setChecked(KateViewConfig::global()->keywordCompletion());
     ui->removeTail->setChecked(KateViewConfig::global()->wordCompletionRemoveTail());
 }
 
@@ -462,6 +461,7 @@ KateEditGeneralConfigTab::KateEditGeneralConfigTab(QWidget *parent)
     connect(ui->chkStaticWordWrap, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(ui->chkShowStaticWordWrapMarker, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(ui->sbWordWrap, SIGNAL(valueChanged(int)), this, SLOT(slotChanged()));
+    connect(ui->chkAutoBrackets, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(ui->chkSmartCopyCut, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(ui->cmbInputMode, SIGNAL(currentIndexChanged(int)), this, SLOT(slotChanged()));
 
@@ -492,21 +492,22 @@ void KateEditGeneralConfigTab::apply()
 
     KateRendererConfig::global()->setWordWrapMarker(ui->chkShowStaticWordWrapMarker->isChecked());
 
-    KateDocumentConfig::global()->configEnd();
+    KateViewConfig::global()->setAutoBrackets(ui->chkAutoBrackets->isChecked());
     KateViewConfig::global()->setSmartCopyCut(ui->chkSmartCopyCut->isChecked());
-    KateViewConfig::global()->configEnd();
 
     KateViewConfig::global()->setInputModeRaw(ui->cmbInputMode->currentData().toInt());
+
+    KateDocumentConfig::global()->configEnd();
+    KateViewConfig::global()->configEnd();
 }
 
 void KateEditGeneralConfigTab::reload()
 {
     ui->chkStaticWordWrap->setChecked(KateDocumentConfig::global()->wordWrap());
     ui->chkShowStaticWordWrapMarker->setChecked(KateRendererConfig::global()->wordWrapMarker());
-    //ui->sbWordWrap->setSuffix(ki18ncp("Wrap words at", " character", " characters").toString());
-    //ui->sbWordWrap->setSpecialValueText(ki18nc("spinbox special value for 1 Wrap words at"," 1 character").toString());//(ki18np(" character", " characters").toString());
-    ui->sbWordWrap->setSuffix(ki18nc("suffix for spinbox >1 wrap words at (value is at 20 or larger)", " characters").toString());
+    ui->sbWordWrap->setSuffix(ki18ncp("Wrap words at (value is at 20 or larger)", " character", " characters"));
     ui->sbWordWrap->setValue(KateDocumentConfig::global()->wordWrapAt());
+    ui->chkAutoBrackets->setChecked(KateViewConfig::global()->autoBrackets());
     ui->chkSmartCopyCut->setChecked(KateViewConfig::global()->smartCopyCut());
 
     const int id = static_cast<int>(KateViewConfig::global()->inputMode());
@@ -671,6 +672,7 @@ KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
     connect(textareaUi->chkShowIndentationLines, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(textareaUi->chkShowWholeBracketExpression, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(textareaUi->chkAnimateBracketMatching, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+    connect(textareaUi->chkFoldFirstLine,  SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
 
     connect(bordersUi->chkIconBorder, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(bordersUi->chkScrollbarMarks, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
@@ -722,6 +724,7 @@ void KateViewDefaultsConfig::apply()
     KateRendererConfig::global()->setShowIndentationLines(textareaUi->chkShowIndentationLines->isChecked());
     KateRendererConfig::global()->setShowWholeBracketExpression(textareaUi->chkShowWholeBracketExpression->isChecked());
     KateRendererConfig::global()->setAnimateBracketMatching(textareaUi->chkAnimateBracketMatching->isChecked());
+    KateViewConfig::global()->setFoldFirstLine(textareaUi->chkFoldFirstLine->isChecked());
 
     KateRendererConfig::global()->configEnd();
     KateViewConfig::global()->configEnd();
@@ -748,6 +751,7 @@ void KateViewDefaultsConfig::reload()
     textareaUi->chkShowIndentationLines->setChecked(KateRendererConfig::global()->showIndentationLines());
     textareaUi->chkShowWholeBracketExpression->setChecked(KateRendererConfig::global()->showWholeBracketExpression());
     textareaUi->chkAnimateBracketMatching->setChecked(KateRendererConfig::global()->animateBracketMatching());
+    textareaUi->chkFoldFirstLine->setChecked(KateViewConfig::global()->foldFirstLine());
 }
 
 void KateViewDefaultsConfig::reset()
@@ -1136,9 +1140,9 @@ void KateHlDownloadDialog::listDataReceived(KIO::Job *, const QByteArray &data)
     }
 
     listData += QLatin1String(data);
-    qCDebug(LOG_PART) << QLatin1String("CurrentListData: ") << listData;
-    qCDebug(LOG_PART) << QString::fromLatin1("Data length: %1").arg(data.size());
-    qCDebug(LOG_PART) << QString::fromLatin1("listData length: %1").arg(listData.length());
+    qCDebug(LOG_KTE) << QLatin1String("CurrentListData: ") << listData;
+    qCDebug(LOG_KTE) << QString::fromLatin1("Data length: %1").arg(data.size());
+    qCDebug(LOG_KTE) << QString::fromLatin1("listData length: %1").arg(listData.length());
     if (data.size() == 0) {
         if (listData.length() > 0) {
             QString installedVersion;
@@ -1150,14 +1154,14 @@ void KateHlDownloadDialog::listDataReceived(KIO::Job *, const QByteArray &data)
             KateHighlighting *hl = 0;
 
             if (n.isNull()) {
-                qCDebug(LOG_PART) << QLatin1String("There is no usable childnode");
+                qCDebug(LOG_KTE) << QLatin1String("There is no usable childnode");
             }
             while (!n.isNull()) {
                 installedVersion = QLatin1String("    --");
 
                 QDomElement e = n.toElement();
                 if (!e.isNull()) {
-                    qCDebug(LOG_PART) << QLatin1String("NAME: ") << e.tagName() << QLatin1String(" - ") << e.attribute(QLatin1String("name"));
+                    qCDebug(LOG_KTE) << QLatin1String("NAME: ") << e.tagName() << QLatin1String(" - ") << e.attribute(QLatin1String("name"));
                 }
                 n = n.nextSibling();
 
@@ -1191,7 +1195,7 @@ void KateHlDownloadDialog::listDataReceived(KIO::Job *, const QByteArray &data)
                 }
                 if (is_fresh) {
                     entry->treeWidget()->setItemSelected(entry, true);
-                    entry->setIcon(0, SmallIcon((QLatin1String("get-hot-new-stuff"))));
+                    entry->setIcon(0, QIcon::fromTheme((QLatin1String("get-hot-new-stuff"))));
                 }
             }
             list->resizeColumnToContents(1);
@@ -1202,7 +1206,7 @@ void KateHlDownloadDialog::listDataReceived(KIO::Job *, const QByteArray &data)
 
 void KateHlDownloadDialog::slotInstall()
 {
-    const QString destdir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/katepart/syntax/");
+    const QString destdir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/katepart5/syntax/");
     QDir(destdir).mkpath(QLatin1String(".")); // make sure the dir is there
 
     foreach (QTreeWidgetItem *it, list->selectedItems()) {
@@ -1220,10 +1224,6 @@ void KateHlDownloadDialog::slotInstall()
         KJobWidgets::setWindow(job, this);
         job->exec();
     }
-
-    // update Config !!
-    // this rewrites the cache....
-    KateSyntaxDocument doc(KateHlManager::self()->getKConfig(), true);
 }
 //END KateHlDownloadDialog
 
@@ -1243,7 +1243,7 @@ KateGotoBar::KateGotoBar(KTextEditor::View *view, QWidget *parent)
 
     QToolButton *btnOK = new QToolButton(centralWidget());
     btnOK->setAutoRaise(true);
-    btnOK->setIcon(SmallIcon(QLatin1String("go-jump")));
+    btnOK->setIcon(QIcon::fromTheme(QLatin1String("go-jump")));
     btnOK->setText(i18n("Go"));
     btnOK->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     connect(btnOK, SIGNAL(clicked()), this, SLOT(gotoLine()));
@@ -1375,7 +1375,7 @@ KateModOnHdPrompt::KateModOnHdPrompt(KTextEditor::DocumentPrivate *doc,
     mainLayout->addWidget(w);
     ui = new Ui::ModOnHdWidget();
     ui->setupUi(w);
-    ui->lblIcon->setPixmap(DesktopIcon(QLatin1String("dialog-warning")));
+    ui->lblIcon->setPixmap(QIcon::fromTheme(QLatin1String("dialog-warning")).pixmap(IconSize(KIconLoader::Desktop), IconSize(KIconLoader::Desktop)));
     ui->lblText->setText(reason + QLatin1String("\n\n") + i18n("What do you want to do?"));
 
     // buttons
@@ -1411,6 +1411,12 @@ KateModOnHdPrompt::KateModOnHdPrompt(KTextEditor::DocumentPrivate *doc,
     } else {
         ui->chkIgnoreWhiteSpaces->setVisible(false);
         ui->btnDiff->setVisible(false);
+
+        QPushButton *closeButton = new QPushButton;
+        KGuiItem::assign(closeButton, KStandardGuiItem::close());
+        closeButton->setToolTip(i18n("Close the document."));
+        buttons->addButton(closeButton, QDialogButtonBox::DestructiveRole);
+        connect(closeButton, SIGNAL(clicked()), this, SLOT(slotClose()));
     }
 }
 
@@ -1536,5 +1542,10 @@ void KateModOnHdPrompt::slotOverwrite()
     done(Overwrite);
 }
 
+void KateModOnHdPrompt::slotClose()
+{
+    done(Close);
+}
+
 //END KateModOnHdPrompt
 
