@@ -213,6 +213,7 @@ public:
     void forceCompletion() Q_DECL_OVERRIDE;
     void registerCompletionModel(KTextEditor::CodeCompletionModel *model) Q_DECL_OVERRIDE;
     void unregisterCompletionModel(KTextEditor::CodeCompletionModel *model) Q_DECL_OVERRIDE;
+    bool isCompletionModelRegistered(KTextEditor::CodeCompletionModel *model) const;
     bool isAutomaticInvocationEnabled() const Q_DECL_OVERRIDE;
     void setAutomaticInvocationEnabled(bool enabled = true) Q_DECL_OVERRIDE;
 
@@ -550,6 +551,7 @@ private Q_SLOTS:
     void slotSelectionChanged();
 
     void toggleInputMode(bool);
+    void cycleInputMode();
 
 public:
     /**
@@ -968,11 +970,5 @@ private:
 
 }
 
-/**
- * metatype register
- */
-Q_DECLARE_METATYPE(KTextEditor::Cursor)
-Q_DECLARE_METATYPE(KTextEditor::Range)
-
 #endif
 
