@@ -500,7 +500,7 @@ void KateScrollBar::miniMapPaintEvent(QPaintEvent *e)
 
     // calculate the visible area
     int max = qMax(maximum() + 1, 1);
-    int visibleStart = value() * docHeight / (max + pageStep()) + docRect.top();
+    int visibleStart = value() * docHeight / (max + pageStep()) + docRect.top() + 0.5;
     int visibleEnd = (value() + pageStep()) * docHeight / (max + pageStep()) + docRect.top();
     QRect visibleRect = docRect;
     visibleRect.moveTop(visibleStart);
@@ -510,6 +510,7 @@ void KateScrollBar::miniMapPaintEvent(QPaintEvent *e)
     // calculate colors
     const QColor backgroundColor = m_view->defaultStyleAttribute(KTextEditor::dsNormal)->background().color();
     const QColor foregroundColor = m_view->defaultStyleAttribute(KTextEditor::dsNormal)->foreground().color();
+    const QColor highlightColor  = palette().link().color();
 
     int backgroundLightness = backgroundColor.lightness();
     int foregroundLightness = foregroundColor.lightness();
@@ -534,43 +535,16 @@ void KateScrollBar::miniMapPaintEvent(QPaintEvent *e)
     outlineColor.setHsl(hue, sat, backgroundLightness + lighnessDiff * 0.5);
 
     // draw the grove background in case the document is small
-    painter.setPen(QPen(QColor("transparent"), 0));
-    painter.setBrush(palette().brush(QPalette::Dark));
+    painter.setPen(Qt::NoPen);
+    painter.setBrush(backgroundColor);
     painter.drawRect(grooveRect);
 
-    // dark "shield" of non-slider parts
-    painter.setBrush(gradient);
-    painter.drawRect(docRect);
-
-    // light "shield" non-visible parts
+    // adjust the rectangles
     if ((docHeight + 2 * docXMargin >= grooveRect.height()) && (sliderRect.height() > visibleRect.height() + 2)) {
-        // slider
-        painter.setPen(QPen(QColor("transparent"), 0));
-        painter.setBrush(lightShieldColor);
-        sliderRect.adjust(1, 0, -1, 0);
-        painter.drawRect(sliderRect);
-
-        // visible area
         visibleRect.adjust(2, 0, -3, 0);
-        painter.setPen(QPen(backgroundColor, 1));
-        painter.setBrush(backgroundColor);
-        painter.drawRect(visibleRect);
-
-        // slider outline
-        painter.setRenderHint(QPainter::Antialiasing);
-        painter.setPen(QPen(outlineColor, 2));
-        painter.setBrush(QColor("transparent"));
-        sliderRect.adjust(-1, 0, 1, 0);
-        painter.drawRoundedRect(sliderRect, 4, 4);
-        painter.setRenderHint(QPainter::Antialiasing, false);
     } else {
-        // visible area with outline
-        painter.setRenderHint(QPainter::Antialiasing);
-        painter.setPen(QPen(outlineColor, 2));
-        painter.setBrush(backgroundColor);
         visibleRect.adjust(1, 0, -1, 2);
-        painter.drawRoundedRect(visibleRect, 4, 4);
-        painter.setRenderHint(QPainter::Antialiasing, false);
+        sliderRect = visibleRect;
     }
 
     // Smooth transform only when squeezing
@@ -583,37 +557,81 @@ void KateScrollBar::miniMapPaintEvent(QPaintEvent *e)
     QRect docPixmapMarginRect(QPoint(0, docRect.top()), QSize(s_pixelMargin, docRect.height()));
     painter.drawPixmap(docPixmapMarginRect, m_pixmap, pixmapMarginRect);
 
-    // calculate the stretch and draw the stretched lines
+    // calculate the stretch and draw the stretched lines (scrollbar marks)
     QRect pixmapRect(QPoint(s_pixelMargin, 0), QSize(m_pixmap.width() - s_pixelMargin, m_pixmap.height()));
     QRect docPixmapRect(QPoint(s_pixelMargin, docRect.top()), QSize(docRect.width() - s_pixelMargin, docRect.height()));
     painter.drawPixmap(docPixmapRect, m_pixmap, pixmapRect);
 
-    if (!m_showMarks) {
-        return;
+    // delimit the end of the document
+    const int y = docPixmapRect.height() + grooveRect.y();
+    if (y+2 < grooveRect.y() + grooveRect.height()) {
+        QColor fg(foregroundColor);
+        fg.setAlpha(30);
+        painter.setBrush(Qt::NoBrush);
+        painter.setPen(QPen(fg, 1));
+        painter.drawLine(grooveRect.x()+1,y+4,width()-1,y+4);
     }
 
-    QHashIterator<int, QColor> it = m_lines;
-    QPen penBg;
-    penBg.setWidth(4);
-    lightShieldColor.setAlpha(180);
-    penBg.setColor(lightShieldColor);
-    painter.setPen(penBg);
-    while (it.hasNext()) {
-        it.next();
-        int y = (it.key() - grooveRect.top()) * docHeight / grooveRect.height() + docRect.top();;
-        painter.drawLine(6, y, width() - 6, y);
+    // fade the invisible sections
+    const QRect top(
+        grooveRect.x(),
+        grooveRect.y(),
+        grooveRect.width(),
+        visibleRect.y()-grooveRect.y() //Pen width
+    );
+    const QRect bottom(
+        grooveRect.x(),
+        grooveRect.y()+visibleRect.y()+visibleRect.height()-grooveRect.y(), //Pen width
+        grooveRect.width(),
+        grooveRect.height() - (visibleRect.y()-grooveRect.y())-visibleRect.height()
+    );
+
+    QColor faded(backgroundColor);
+    faded.setAlpha(110);
+    painter.setPen(Qt::NoPen);
+    painter.setBrush(faded);
+    painter.drawRect(top);
+    painter.drawRect(bottom);
+
+    // add a thin line to delimitate the scrollbar
+    QColor c(foregroundColor);
+    c.setAlpha(10);
+    painter.setPen(QPen(c,1));
+    painter.drawLine(0, 0, 0, height());
+
+    if (m_showMarks) {
+        QHashIterator<int, QColor> it = m_lines;
+        QPen penBg;
+        penBg.setWidth(4);
+        lightShieldColor.setAlpha(180);
+        penBg.setColor(lightShieldColor);
+        painter.setPen(penBg);
+        while (it.hasNext()) {
+            it.next();
+            int y = (it.key() - grooveRect.top()) * docHeight / grooveRect.height() + docRect.top();;
+            painter.drawLine(6, y, width() - 6, y);
+        }
+
+        it = m_lines;
+        QPen pen;
+        pen.setWidth(2);
+        while (it.hasNext()) {
+            it.next();
+            pen.setColor(it.value());
+            painter.setPen(pen);
+            int y = (it.key() - grooveRect.top()) * docHeight / grooveRect.height() + docRect.top();
+            painter.drawLine(6, y, width() - 6, y);
+        }
     }
 
-    it = m_lines;
-    QPen pen;
-    pen.setWidth(2);
-    while (it.hasNext()) {
-        it.next();
-        pen.setColor(it.value());
-        painter.setPen(pen);
-        int y = (it.key() - grooveRect.top()) * docHeight / grooveRect.height() + docRect.top();;
-        painter.drawLine(6, y, width() - 6, y);
-    }
+    // slider outline
+    QColor sliderColor(highlightColor);
+    sliderColor.setAlpha(50);
+    painter.setRenderHint(QPainter::Antialiasing);
+    painter.setPen(QPen(highlightColor,1));
+    painter.setBrush(sliderColor);
+    painter.drawRoundedRect(sliderRect, 3, 3);
+    painter.setRenderHint(QPainter::Antialiasing, false);
 }
 
 void KateScrollBar::normalPaintEvent(QPaintEvent *e)
@@ -958,41 +976,38 @@ void KateCmdLineEdit::slotReturnPressed(const QString &text)
             emit hideRequested();
         }
 
-        // we got a range and a valid command, but the command does not inherit the RangeCommand
-        // extension. bail out.
-        if (range.isValid() && !p->supportsRange(cmd)) {
+        if (!p) {
+            setText(i18n("No such command: \"%1\"",  cmd));
+        } else if (range.isValid() && !p->supportsRange(cmd)) {
+            // we got a range and a valid command, but the command does not inherit the RangeCommand
+            // extension. bail out.
             setText(i18n("Error: No range allowed for command \"%1\".",  cmd));
         } else {
+            QString msg;
+            if (p->exec(m_view, cmd, msg, range)) {
 
-            if (p) {
-                QString msg;
-                if (p->exec(m_view, cmd, msg, range)) {
+                // append command along with range (will be empty if none given) to history
+                KateCmd::self()->appendHistory(leadingRangeExpression + cmd);
+                m_histpos = KateCmd::self()->historyLength();
+                m_oldText.clear();
 
-                    // append command along with range (will be empty if none given) to history
-                    KateCmd::self()->appendHistory(leadingRangeExpression + cmd);
-                    m_histpos = KateCmd::self()->historyLength();
-                    m_oldText.clear();
-
-                    if (msg.length() > 0) {
-                        setText(i18n("Success: ") + msg);
-                    } else if (isVisible()) {
-                        // always hide on success without message
-                        emit hideRequested();
-                    }
-                } else {
-                    if (msg.length() > 0) {
-                        if (msg.contains(QLatin1Char('\n'))) {
-                            // multiline error, use widget with more space
-                            QWhatsThis::showText(mapToGlobal(QPoint(0, 0)), msg);
-                        } else {
-                            setText(msg);
-                        }
-                    } else {
-                        setText(i18n("Command \"%1\" failed.",  cmd));
-                    }
+                if (msg.length() > 0) {
+                    setText(i18n("Success: ") + msg);
+                } else if (isVisible()) {
+                    // always hide on success without message
+                    emit hideRequested();
                 }
             } else {
-                setText(i18n("No such command: \"%1\"",  cmd));
+                if (msg.length() > 0) {
+                    if (msg.contains(QLatin1Char('\n'))) {
+                        // multiline error, use widget with more space
+                        QWhatsThis::showText(mapToGlobal(QPoint(0, 0)), msg);
+                    } else {
+                        setText(msg);
+                    }
+                } else {
+                    setText(i18n("Command \"%1\" failed.",  cmd));
+                }
             }
         }
     }
@@ -1269,12 +1284,14 @@ void KateIconBorder::setRelLineNumbersOn(bool enable)
     QTimer::singleShot( 0, this, SLOT(update()) );
 }
 
-void KateIconBorder::updateRelLineNumbers()
+void KateIconBorder::updateForCursorLineChange()
 {
     if (m_relLineNumbersOn) {
         m_updateRelLineNumbers = true;
-        update();
     }
+
+    // always do normal update, e.g. for different current line color!
+    update();
 }
 
 void KateIconBorder::setDynWrapIndicators(int state)
@@ -1370,9 +1387,10 @@ int KateIconBorder::lineNumberWidth() const
             int w = 16;// HACK: 16 == style().scrollBarExtent().width() style().scrollBarExtent().width();
             int h = m_view->renderer()->lineHeight();
 
-            QSize newSize(w, h);
+            QSize newSize(w * devicePixelRatio(), h * devicePixelRatio());
             if ((m_arrow.size() != newSize || m_oldBackgroundColor != m_view->renderer()->config()->iconBarColor()) && !newSize.isEmpty()) {
                 m_arrow = QPixmap(newSize);
+                m_arrow.setDevicePixelRatio(devicePixelRatio());
 
                 QPainter p(&m_arrow);
                 p.fillRect(0, 0, w, h, m_view->renderer()->config()->iconBarColor());
@@ -1630,7 +1648,7 @@ void KateIconBorder::paintBorder(int /*x*/, int y, int /*width*/, int height)
                                    Qt::TextDontClip | Qt::AlignRight | Qt::AlignVCenter, QString::fromLatin1("%1").arg(realLine + 1));
                     }
                 } else if (m_view->dynWordWrap() && m_dynWrapIndicatorsOn) {
-                    p.drawPixmap(lnX + lnWidth - m_arrow.width() - 2, y, m_arrow);
+                    p.drawPixmap(lnX + lnWidth - (m_arrow.width() / m_arrow.devicePixelRatio()) - 2, y, m_arrow);
                 }
             }
 
@@ -1787,6 +1805,9 @@ void KateIconBorder::showBlock()
         return;
     }
     m_currentBlockLine = m_nextHighlightBlock;
+    if (m_currentBlockLine >= m_doc->buffer().lines()) {
+        return;
+    }
 
     /**
      * compute to which folding range we belong
@@ -1905,10 +1926,8 @@ void KateIconBorder::mouseMoveEvent(QMouseEvent *e)
 
 void KateIconBorder::mouseReleaseEvent(QMouseEvent *e)
 {
-    int cursorOnLine = m_viewInternal->yToKateTextLayout(e->y()).line();
-
-    if (cursorOnLine == m_lastClickedLine &&
-            cursorOnLine <= m_doc->lastLine()) {
+    const int cursorOnLine = m_viewInternal->yToKateTextLayout(e->y()).line();
+    if (cursorOnLine == m_lastClickedLine && cursorOnLine >= 0 && cursorOnLine <= m_doc->lastLine()) {
         BorderArea area = positionToArea(e->pos());
         if (area == IconBorder) {
             if (e->button() == Qt::LeftButton) {
@@ -2197,8 +2216,9 @@ void KateViewEncodingAction::Private::_k_subActionTriggered(QAction *action)
     }
 }
 
-KateViewEncodingAction::KateViewEncodingAction(KTextEditor::DocumentPrivate *_doc, KTextEditor::ViewPrivate *_view, const QString &text, QObject *parent)
+KateViewEncodingAction::KateViewEncodingAction(KTextEditor::DocumentPrivate *_doc, KTextEditor::ViewPrivate *_view, const QString &text, QObject *parent, bool saveAsMode)
     : KSelectAction(text, parent), doc(_doc), view(_view), d(new Private(this))
+    , m_saveAsMode(saveAsMode)
 {
     d->init();
 
@@ -2218,6 +2238,17 @@ void KateViewEncodingAction::slotAboutToShow()
 
 void KateViewEncodingAction::setEncoding(const QString &e)
 {
+    /**
+     * in save as mode => trigger saveAs
+     */
+    if (m_saveAsMode) {
+        doc->documentSaveAsWithEncoding(e);
+        return;
+    }
+
+    /**
+     * else switch encoding
+     */
     doc->userSetEncodingForNextReload();
     doc->setEncoding(e);
     view->reloadFile();
@@ -2476,6 +2507,15 @@ void KateViewBar::setViewBarVisible(bool visible)
     }
 }
 
+bool KateViewBar::hiddenOrPermanent() const
+{
+    KateViewBarWidget *current = qobject_cast<KateViewBarWidget *>(m_stack->currentWidget());
+    if (!isVisible() || (m_permanentBarWidget && m_permanentBarWidget == current)) {
+        return true;
+    }
+    return false;
+}
+
 void KateViewBar::keyPressEvent(QKeyEvent *event)
 {
     if (event->key() == Qt::Key_Escape) {
