@@ -64,7 +64,7 @@ namespace
     // fifth, sixth and seventh groups are contingent on the fourth group.
     inline const QRegularExpression& RE_CmdRange()
     {
-        static const QRegularExpression regex(QStringLiteral("^(" RE_POSITION ")((?:,(" RE_POSITION "))?)"));
+        static const QRegularExpression regex(QLatin1String("^(" RE_POSITION ")((?:,(" RE_POSITION "))?)"));
         return regex;
     }
 }
@@ -229,7 +229,7 @@ bool CommandRangeExpressionParser::matchForwardSearch(const QString &line, QList
 
     QString pattern = match.captured(1);
     KTextEditor::Range range(m_viInputModeManager->view()->cursorPosition(), m_viInputModeManager->view()->doc()->documentEnd());
-    QVector<KTextEditor::Range> matchingLines = m_viInputModeManager->view()->doc()->searchText(range, pattern, KTextEditor::Search::Regex);
+    QVector<KTextEditor::Range> matchingLines = m_viInputModeManager->view()->doc()->searchText(range, pattern, KTextEditor::Regex);
 
     if (matchingLines.isEmpty()) {
         return true;
@@ -251,7 +251,7 @@ bool CommandRangeExpressionParser::matchBackwardSearch(const QString &line, QLis
 
     QString pattern = match.captured(1);
     KTextEditor::Range range(KTextEditor::Cursor(0,0), m_viInputModeManager->view()->cursorPosition());
-    QVector<KTextEditor::Range> matchingLines = m_viInputModeManager->view()->doc()->searchText(range, pattern, KTextEditor::Search::Regex);
+    QVector<KTextEditor::Range> matchingLines = m_viInputModeManager->view()->doc()->searchText(range, pattern, KTextEditor::Regex);
 
     if (matchingLines.isEmpty()) {
         return true;
